# gamesave

Update 1.0.1: Changable file encoding via settings! Also, small bug fixes.

a small module to make hobbyist game development easier; <br>
includes Base64 support for save files.

a very simple library, probably won't get updates unless people use it :P
